@@ -18,6 +18,10 @@ impl Slice {
     pub fn new(axis: usize, start: impl ToDim, end: impl ToDim) -> Slice {
         Slice { axis, start: start.to_dim(), end: end.to_dim() }
     }
+
+    pub fn suffix(&self) -> String {
+        format!("axis{}_{}_{}", self.axis, self.start, self.end)
+    }
 }
 
 impl Op for Slice {
@@ -67,7 +71,11 @@ impl TypedOp for Slice {
         Ok(tvec!(fact))
     }
 
-    fn invariants(&self, inputs: &[&TypedFact], _outputs: &[&TypedFact]) -> TractResult<Invariants> {
+    fn invariants(
+        &self,
+        inputs: &[&TypedFact],
+        _outputs: &[&TypedFact],
+    ) -> TractResult<Invariants> {
         let axes = (0..inputs[0].rank())
             .filter(|&ax| self.axis != ax)
             .map(|axis| AxisInfo::simple(axis))
@@ -118,6 +126,7 @@ impl TypedOp for Slice {
             model,
             prec,
             &mut patch,
+            &self.suffix(),
             node.inputs[0].slot,
             self.axis,
             start,
@@ -142,6 +151,7 @@ impl TypedOp for Slice {
         model: &TypedModel,
         node: &TypedNode,
         patch: &mut TypedModelPatch,
+        suffix: &str,
         _output_slot: usize,
         axis: usize,
         start: usize,
@@ -149,16 +159,33 @@ impl TypedOp for Slice {
     ) -> TractResult<Option<OutletId>> {
         let prec = model.node(node.inputs[0].node);
         if axis != self.axis {
+            let suffix = suffix.to_string() + "." + &self.suffix();
             return prec
                 .op()
                 .as_typed()
                 .unwrap()
-                .slice_output(model, &prec, patch, node.inputs[0].slot, axis, start, end)?
-                .map(|w| Ok(patch.wire_node(&node.name, self.clone(), &[w])?[0]))
+                .slice_output(model, &prec, patch, &suffix, node.inputs[0].slot, axis, start, end)?
+                .map(|w| {
+                    Ok(patch.wire_node(format!("{}.{}", node.name, &suffix), self.clone(), &[w])?[0])
+                })
                 .transpose();
         }
         Ok(None)
     }
 
+    fn concretize_dims(
+        &self,
+        _source: &TypedModel,
+        node: &TypedNode,
+        target: &mut TypedModel,
+        mapping: &HashMap<OutletId, OutletId>,
+        values: &SymbolValues,
+    ) -> TractResult<TVec<OutletId>> {
+        let op =
+            Slice { axis: self.axis, start: self.start.eval(values), end: self.end.eval(values) };
+        let inputs = node.inputs.iter().map(|i| mapping[i]).collect::<TVec<_>>();
+        target.wire_node(&node.name, op, &inputs)
+    }
+
     as_op!();
 }
